
# Milvus Python SDK

[![version](https://img.shields.io/pypi/v/pymilvus.svg?color=blue)](https://pypi.org/project/pymilvus/)
[![Downloads](https://pepy.tech/badge/pymilvus)](https://pepy.tech/project/pymilvus)
[![Downloads](https://pepy.tech/badge/pymilvus/month)](https://pepy.tech/project/pymilvus/month)
[![Downloads](https://pepy.tech/badge/pymilvus/week)](https://pepy.tech/project/pymilvus/week)
[![license](https://img.shields.io/hexpm/l/plug.svg?color=green)](https://github.com/milvus-io/pymilvus/blob/master/LICENSE)

Python SDK for [Milvus](https://github.com/milvus-io/milvus). To contribute code to this project, please read our [contribution guidelines](https://github.com/milvus-io/milvus/blob/master/CONTRIBUTING.md) first.


## Compatibility
The following collection shows Milvus versions and recommended PyMilvus versions:

|Milvus version| Recommended PyMilvus version |
|:-----:|:-----:|
| 1.0.0 | 1.0.1 |


## Installation

You can install PyMilvus via `pip` or `pip3` for Python 3.6+:

```shell
$ pip3 install pymilvus
```

You can install a specific version of PyMilvus by:

```shell
$ pip install pymilvus==1.0.1
```

You can upgrade PyMilvus to the latest version by:

```shell
$ pip install --upgrade pymilvus
```



## Documentation

Documentation is available online: https://pymilvus.readthedocs.io/.



## License
[Apache License 2.0](LICENSE)
